summaryrefslogtreecommitdiff
path: root/lisp/follow.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/follow.el')
-rw-r--r--lisp/follow.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/lisp/follow.el b/lisp/follow.el
index 2d818708c63..fcdfd4db2e9 100644
--- a/lisp/follow.el
+++ b/lisp/follow.el
@@ -6,7 +6,7 @@
;; Maintainer: Anders Lindgren <andersl@csd.uu.se>
;; Created: 25 May 1995
;; Version: 1.7
;; Keywords: display, window, minor-mode
;; Date: 4 Jun 1997
;; This file is part of GNU Emacs.
@@ -281,7 +281,8 @@
(defgroup follow nil
"Synchronize windows showing the same buffer."
:prefix "follow-"
- :group 'windows)
+ :group 'windows
+ :group 'convenience)
(defvar follow-mode nil
"Variable indicating if Follow mode is active.")
@@ -6,7 +6,7 @@
;; Created: 25 May 1995
;; Version: 1.7
-;; Keywords: display, window, minor-mode
+;; Keywords: display, window, minor-mode, convenience
;; Date: 4 Jun 1997
;; This file is part of GNU Emacs.